#[repr(C)]pub struct BatterySimulatorControllerSetRemainingChargeUahRequest {
pub charge: u32,
}Fields
charge: u32Trait Implementations
Sourceimpl Clone for BatterySimulatorControllerSetRemainingChargeUahRequest
impl Clone for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourcefn clone(&self) -> BatterySimulatorControllerSetRemainingChargeUahRequest
fn clone(&self) -> BatterySimulatorControllerSetRemainingChargeUahRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for BatterySimulatorControllerSetRemainingChargeUahRequest
impl<D: ResourceDialect> Decode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourceimpl<D: ResourceDialect> Encode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for &BatterySimulatorControllerSetRemainingChargeUahRequest
impl<D: ResourceDialect> Encode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for &BatterySimulatorControllerSetRemainingChargeUahRequest
Sourceimpl<D: ResourceDialect, T0: Encode<u32, D>> Encode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<u32, D>> Encode<BatterySimulatorControllerSetRemainingChargeUahRequest, D> for (T0,)
Sourceimpl Ord for BatterySimulatorControllerSetRemainingChargeUahRequest
impl Ord for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourcefn cmp(
&self,
other: &BatterySimulatorControllerSetRemainingChargeUahRequest,
) -> Ordering
fn cmp( &self, other: &BatterySimulatorControllerSetRemainingChargeUahRequest, ) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BatterySimulatorControllerSetRemainingChargeUahRequest
impl PartialEq for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourcefn eq(
&self,
other: &BatterySimulatorControllerSetRemainingChargeUahRequest,
) -> bool
fn eq( &self, other: &BatterySimulatorControllerSetRemainingChargeUahRequest, ) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BatterySimulatorControllerSetRemainingChargeUahRequest
impl PartialOrd for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourceimpl TypeMarker for BatterySimulatorControllerSetRemainingChargeUahRequest
impl TypeMarker for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourcetype Owned = BatterySimulatorControllerSetRemainingChargeUahRequest
type Owned = BatterySimulatorControllerSetRemainingChargeUahRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BatterySimulatorControllerSetRemainingChargeUahRequest
impl ValueTypeMarker for BatterySimulatorControllerSetRemainingChargeUahRequest
Sourcetype Borrowed<'a> = &'a BatterySimulatorControllerSetRemainingChargeUahRequest
type Borrowed<'a> = &'a BatterySimulatorControllerSetRemainingChargeUahRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for BatterySimulatorControllerSetRemainingChargeUahRequest
impl Eq for BatterySimulatorControllerSetRemainingChargeUahRequest
impl Persistable for BatterySimulatorControllerSetRemainingChargeUahRequest
impl StructuralPartialEq for BatterySimulatorControllerSetRemainingChargeUahRequest